@@ -11,19 +11,18 @@ use crate::{
     },
     error::MetadataError,
     instruction::MetadataInstruction,
+    solana_program::program_memory::sol_memset,
     state::{
         Collection, CollectionAuthorityRecord, DataV2, Key, MasterEditionV1, MasterEditionV2,
         Metadata, TokenStandard, UseAuthorityRecord, UseMethod, Uses, BURN, COLLECTION_AUTHORITY,
         COLLECTION_AUTHORITY_RECORD_SIZE, EDITION, MAX_MASTER_EDITION_LEN, PREFIX, USER,
         USE_AUTHORITY_RECORD_SIZE,
     },
-    solana_program::{
-        program_memory::{sol_memset},
-    },
     utils::{
-        assert_currently_holding, assert_data_valid, assert_derivation, assert_initialized,
-        assert_mint_authority_matches_mint, assert_owned_by, assert_signer, assert_delegated_tokens,
-        assert_token_program_matches_package, assert_update_authority_is_correct, assert_freeze_authority_matches_mint,
+        assert_currently_holding, assert_data_valid, assert_delegated_tokens, assert_derivation,
+        assert_freeze_authority_matches_mint, assert_initialized,
+        assert_mint_authority_matches_mint, assert_owned_by, assert_signer,
+        assert_token_program_matches_package, assert_update_authority_is_correct,
         create_or_allocate_account_raw, get_owner_from_token_account,
         process_create_metadata_accounts_logic,
         process_mint_new_edition_from_master_edition_via_token_logic, puff_out_data_fields,
@@ -43,7 +42,7 @@ use solana_program::{
     pubkey::Pubkey,
 };
 use spl_token::{
-    instruction::{approve, revoke, freeze_account, thaw_account},
+    instruction::{approve, freeze_account, revoke, thaw_account},
     state::{Account, Mint},
 };
 
@@ -376,7 +375,10 @@ pub fn process_sign_metadata(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
     Ok(())
 }
 
-pub fn process_remove_creator_verification(program_id: &Pubkey, accounts: &[AccountInfo]) -> ProgramResult {
+pub fn process_remove_creator_verification(
+    program_id: &Pubkey,
+    accounts: &[AccountInfo],
+) -> ProgramResult {
     let account_info_iter = &mut accounts.iter();
 
     let metadata_info = next_account_info(account_info_iter)?;
@@ -584,7 +586,7 @@ pub fn process_convert_master_edition_v1_to_v2(
         supply: master_edition.supply,
         max_supply: master_edition.max_supply,
     }
-        .serialize(&mut *master_edition_info.try_borrow_mut_data()?)?;
+    .serialize(&mut *master_edition_info.try_borrow_mut_data()?)?;
 
     Ok(())
 }
@@ -876,10 +878,7 @@ pub fn process_approve_use_authority(
         &user_info.key.as_ref(),
         &[bump_seed],
     ];
-    process_use_authority_validation(
-        use_authority_record_info.data_len(),
-        true,
-    )?;
+    process_use_authority_validation(use_authority_record_info.data_len(), true)?;
     create_or_allocate_account_raw(
         *program_id,
         use_authority_record_info,
@@ -903,7 +902,7 @@ pub fn process_approve_use_authority(
                 &[],
                 1,
             )
-                .unwrap(),
+            .unwrap(),
             &[
                 token_program_account_info.clone(),
                 token_account_info.clone(),
@@ -950,10 +949,7 @@ pub fn process_revoke_use_authority(
         token_account_info,
     )?;
     let data = &mut use_authority_record_info.try_borrow_mut_data()?;
-    process_use_authority_validation(
-        data.len(),
-        false,
-    )?;
+    process_use_authority_validation(data.len(), false)?;
     assert_owned_by(use_authority_record_info, program_id)?;
     let canonical_bump = assert_use_authority_derivation(
         program_id,
@@ -965,10 +961,7 @@ pub fn process_revoke_use_authority(
     if record.bump_empty() {
         record.bump = canonical_bump;
     }
-    assert_valid_bump(
-        canonical_bump,
-        &record,
-    )?;
+    assert_valid_bump(canonical_bump, &record)?;
     let metadata_uses = metadata.uses.unwrap();
     if metadata_uses.use_method == UseMethod::Burn {
         invoke(
@@ -978,7 +971,7 @@ pub fn process_revoke_use_authority(
                 &owner_info.key,
                 &[],
             )
-                .unwrap(),
+            .unwrap(),
             &[
                 token_program_account_info.clone(),
                 token_account_info.clone(),
@@ -1046,10 +1039,7 @@ pub fn process_utilize(
     if approved_authority_is_using {
         let use_authority_record_info = next_account_info(account_info_iter)?;
         let data = &mut *use_authority_record_info.try_borrow_mut_data()?;
-        process_use_authority_validation(
-            data.len(),
-            false,
-        )?;
+        process_use_authority_validation(data.len(), false)?;
         assert_owned_by(use_authority_record_info, program_id)?;
         let canonical_bump = assert_use_authority_derivation(
             program_id,
@@ -1062,10 +1052,7 @@ pub fn process_utilize(
         if record.bump_empty() {
             record.bump = canonical_bump;
         }
-        assert_valid_bump(
-            canonical_bump,
-            &record,
-        )?;
+        assert_valid_bump(canonical_bump, &record)?;
         record.allowed_uses = record
             .allowed_uses
             .checked_sub(number_of_uses)
@@ -1079,7 +1066,6 @@ pub fn process_utilize(
     metadata.serialize(&mut *metadata_info.try_borrow_mut_data()?)?;
     if remaining_uses <= 0 && must_burn {
         if approved_authority_is_using {
-            let burn_path = &[PREFIX.as_bytes(), program_id.as_ref(), BURN.as_bytes()];
             let burn_authority_info = next_account_info(account_info_iter)?;
             let seed = assert_burner(burn_authority_info.key)?;
             let burn_bump_ref = &[
@@ -1206,7 +1192,11 @@ pub fn process_revoke_collection_authority(
         .lamports()
         .checked_add(lamports)
         .ok_or(MetadataError::NumericalOverflowError)?;
-    sol_memset(*collection_authority_record.try_borrow_mut_data()?, 0, USE_AUTHORITY_RECORD_SIZE);
+    sol_memset(
+        *collection_authority_record.try_borrow_mut_data()?,
+        0,
+        USE_AUTHORITY_RECORD_SIZE,
+    );
 
     Ok(())
 }
@@ -1282,19 +1272,14 @@ pub fn process_freeze_delegated_account(
         return Err(MetadataError::InvalidTokenProgram.into());
     }
 
-    // assert that edition pda is the freeze authority of this mint 
+    // assert that edition pda is the freeze authority of this mint
     let mint: Mint = assert_initialized(mint_info)?;
     assert_owned_by(edition_info, program_id)?;
     assert_freeze_authority_matches_mint(&mint.freeze_authority, edition_info)?;
 
     // assert delegate is signer and delegated tokens
     assert_signer(&delegate_info)?;
-    assert_delegated_tokens(
-        delegate_info,
-        mint_info,
-        token_account_info,
-    )?;
-
+    assert_delegated_tokens(delegate_info, mint_info, token_account_info)?;
 
     let edition_info_path = Vec::from([
         PREFIX.as_bytes(),
@@ -1317,7 +1302,7 @@ pub fn process_freeze_delegated_account(
             &edition_info.key,
             &[],
         )
-            .unwrap(),
+        .unwrap(),
         &[
             token_account_info.clone(),
             mint_info.clone(),
@@ -1342,18 +1327,14 @@ pub fn process_thaw_delegated_account(
         return Err(MetadataError::InvalidTokenProgram.into());
     }
 
-    // assert that edition pda is the freeze authority of this mint 
+    // assert that edition pda is the freeze authority of this mint
     let mint: Mint = assert_initialized(mint_info)?;
     assert_owned_by(edition_info, program_id)?;
     assert_freeze_authority_matches_mint(&mint.freeze_authority, edition_info)?;
 
     // assert delegate is signer and delegated tokens
     assert_signer(&delegate_info)?;
-    assert_delegated_tokens(
-        delegate_info,
-        mint_info,
-        token_account_info,
-    )?;
+    assert_delegated_tokens(delegate_info, mint_info, token_account_info)?;
 
     let edition_info_path = Vec::from([
         PREFIX.as_bytes(),
@@ -1376,7 +1357,7 @@ pub fn process_thaw_delegated_account(
             &edition_info.key,
             &[],
         )
-            .unwrap(),
+        .unwrap(),
         &[
             token_account_info.clone(),
             mint_info.clone(),
